@@ -1,28 +1,29 @@
-
 #' Calculate Distribution of Complexities by Sample
 #'
 #' @description Calculate the distribution of susceptibilities by sample id.
-#' 
+#'
 #' @inheritParams summarize_gene
 #' @examplesIf interactive()
-#' 
+#'
 #' # Using the built-in data set, `P_sojae_survey`
 #' data(P_sojae_survey)
 #'
 #' P_sojae_survey
 #'
 #' # calculate susceptibilities with a 60 % cutoff value
-#' complexities <- calculate_complexities(x = P_sojae_survey,
-#'                                        cutoff = 60,
-#'                                        control = "susceptible",
-#'                                        sample = "Isolate",
-#'                                        gene = "Rps",
-#'                                        perc_susc = "perc.susc")
+#' complexities <- calculate_complexities(
+#'   x = P_sojae_survey,
+#'   cutoff = 60,
+#'   control = "susceptible",
+#'   sample = "Isolate",
+#'   gene = "Rps",
+#'   perc_susc = "perc.susc"
+#' )
 #' complexities
 #'
 #' summary(complexities)
 #'
-#' @return An object of class `hagis.complexities`.
+#' @returns An object of class `hagis.complexities`.
 #'
 #' An object of class `hagis.complexities` is a `list` containing the following
 #'  components
@@ -32,16 +33,18 @@
 #'     \item{individual_complexities}{a [data.table::data.table()] object of
 #'       individual complexities}
 #'   }
-#'   
+#'
 #' @autoglobal
 #' @export calculate_complexities
 
-calculate_complexities <- function(x,
-                                   cutoff,
-                                   control,
-                                   sample,
-                                   gene,
-                                   perc_susc) {
+calculate_complexities <- function(
+  x,
+  cutoff,
+  control,
+  sample,
+  gene,
+  perc_susc
+) {
   # check inputs and rename columns to work with this package
   x <- .check_inputs(
     .x = x,
@@ -51,7 +54,7 @@ calculate_complexities <- function(x,
     .gene = gene,
     .perc_susc = perc_susc
   )
-  
+
   # The susceptible control is removed from all samples in the data set so that
   #  it will not affect complexity calculations and a new data set is made that
   #  it does not contain susceptible controls.
@@ -96,14 +99,18 @@ calculate_complexities <- function(x,
 
   # set NA to 0 for distribution
   grouped_complexities[is.na(distribution), distribution := 0]
-  setcolorder(grouped_complexities,
-                          neworder = c("N_samp", "frequency", "distribution"))
-  setnames(grouped_complexities,
-                       c("complexity", "frequency", "distribution"))
+  setcolorder(
+    grouped_complexities,
+    neworder = c("N_samp", "frequency", "distribution")
+  )
+  setnames(
+    grouped_complexities,
+    c("complexity", "frequency", "distribution")
+  )
   complexities <-
     list(grouped_complexities, individual_complexities)
   names(complexities) <-
-    c("grouped_complexities", "indvidual_complexities")
+    c("grouped_complexities", "individual_complexities")
 
   # Set new class
   class(complexities) <- union("hagis.complexities", class(x))
@@ -134,12 +141,14 @@ calculate_complexities <- function(x,
 #' data(P_sojae_survey)
 #'
 #' # calculate susceptibilities with a 60 % cutoff value
-#' complexities <- calculate_complexities(x = P_sojae_survey,
-#'                                        cutoff = 60,
-#'                                        control = "susceptible",
-#'                                        sample = "Isolate",
-#'                                        gene = "Rps",
-#'                                        perc_susc = "perc.susc")
+#' complexities <- calculate_complexities(
+#'   x = P_sojae_survey,
+#'   cutoff = 60,
+#'   control = "susceptible",
+#'   sample = "Isolate",
+#'   gene = "Rps",
+#'   perc_susc = "perc.susc"
+#' )
 #'
 #' # Visualize the distribution (count or actual values)
 #' autoplot(complexities, type = "count")
@@ -147,49 +156,59 @@ calculate_complexities <- function(x,
 #' # Visualize the frequency (percentages)
 #' autoplot(complexities, type = "percentage")
 #'
-#' @return A \CRANpkg{ggplot2} object
+#' @returns A \CRANpkg{ggplot2} object
 #' @method autoplot hagis.complexities
 #' @export
 
 autoplot.hagis.complexities <-
-  function(object,
-           type,
-           color = NULL,
-           order = NULL,
-           ...) {
-
+  function(object, type, color = NULL, order = NULL, ...) {
     # create a single data.frame to use in the ggplot call
     z <- object[[1]]
 
     # order cols based on user input
     if (!is.null(order)) {
       if (order == "ascending") {
-        setorder(x = z,
-                             cols = frequency)
+        setorder(
+          x = z,
+          cols = frequency
+        )
         z$order <- seq_len(nrow(z))
       } else if (order == "descending") {
-        setorder(x = z,
-                             cols = -frequency)
+        setorder(
+          x = z,
+          cols = -frequency
+        )
         z$order <- seq_len(nrow(z))
       }
-    } else
+    } else {
       # if no order is specified
       setorder(x = z, cols = complexity)
+    }
     z$order <- seq_len(nrow(z))
 
     plot_percentage <- function(.data, .color) {
-      perc_plot <- ggplot2::ggplot(data = .data,
-                                   ggplot2::aes(x = stats::reorder(complexity,
-                                                                   order),
-                                                y = frequency)) +
-        ggplot2::labs(y = "Percent of samples",
-                      x = "Complexity") +
+      perc_plot <- ggplot2::ggplot(
+        data = .data,
+        ggplot2::aes(
+          x = stats::reorder(
+            complexity,
+            order
+          ),
+          y = frequency
+        )
+      ) +
+        ggplot2::labs(
+          y = "Percent of samples",
+          x = "Complexity"
+        ) +
         ggplot2::ggtitle("Percentage of isolates per complexity")
 
       if (!is.null(.color)) {
         perc_plot +
-          ggplot2::geom_col(fill = .color,
-                            colour = .color)
+          ggplot2::geom_col(
+            fill = .color,
+            colour = .color
+          )
       } else {
         perc_plot +
           ggplot2::geom_col()
@@ -197,18 +216,28 @@ autoplot.hagis.complexities <-
     }
 
     plot_count <- function(.data, .color) {
-      num_plot <- ggplot2::ggplot(data = .data,
-                                  ggplot2::aes(x = stats::reorder(complexity,
-                                                                  order),
-                                               y = distribution)) +
-        ggplot2::labs(y = "Number of samples",
-                      x = "Complexity") +
+      num_plot <- ggplot2::ggplot(
+        data = .data,
+        ggplot2::aes(
+          x = stats::reorder(
+            complexity,
+            order
+          ),
+          y = distribution
+        )
+      ) +
+        ggplot2::labs(
+          y = "Number of samples",
+          x = "Complexity"
+        ) +
         ggplot2::ggtitle("Number of samples per pathotype complexity")
 
       if (!is.null(.color)) {
         num_plot +
-          ggplot2::geom_col(fill = .color,
-                            colour = .color)
+          ggplot2::geom_col(
+            fill = .color,
+            colour = .color
+          )
       } else {
         num_plot +
           ggplot2::geom_col()
@@ -220,8 +249,10 @@ autoplot.hagis.complexities <-
     } else if (type == "count") {
       plot_count(.data = z, .color = color)
     } else {
-      stop(.call = FALSE,
-           "You have entered an invalid `type`.")
+      stop(
+        .call = FALSE,
+        "You have entered an invalid `type`."
+      )
     }
   }
 
@@ -233,8 +264,9 @@ autoplot.hagis.complexities <-
 #'
 #' @param x A \CRANpkg{hagis} `complexities` object generated by
 #'  [calculate_complexities()]. `Character`.
-#' @return A `data.table` that tallies the results by sample.
-#' @noRd
+#' @returns A `data.table` that tallies the results by sample.
+#' @autoglobal
+#' @dev
 .create_summary_isolate <- function(.y) {
   .y <- .y[, list(N_samp = sum(susceptible.1)), by = list(sample)]
   return(.y)
@@ -249,11 +281,11 @@ autoplot.hagis.complexities <-
 #' @noRd
 #' @export
 summary.hagis.complexities <- function(object, ...) {
-  mn <- mean(object$indvidual_complexities$N_samp)
-  sd <- sd(object$indvidual_complexities$N_samp)
+  mn <- mean(object$individual_complexities$N_samp)
+  sd <- sd(object$individual_complexities$N_samp)
   se <- sqrt(
-    stats::var(object$indvidual_complexities$N_samp) /
-      length(object$indvidual_complexities$N_samp)
+    stats::var(object$individual_complexities$N_samp) /
+      length(object$individual_complexities$N_samp)
   )
 
   x <- data.frame(mn, sd, se)
@@ -270,10 +302,14 @@ summary.hagis.complexities <- function(object, ...) {
 #' @param ... ignored
 #' @export
 #' @noRd
-print.summary.complexities <- function(x,
-                                       digits = max(3L,
-                                                    getOption("digits") - 3L),
-                                       ...) {
+print.summary.complexities <- function(
+  x,
+  digits = max(
+    3L,
+    getOption("digits") - 3L
+  ),
+  ...
+) {
   cat("\nMean of Complexities\n")
   cat(x$mean, "\n")
   cat("\nStandard Deviation of Complexities\n")
@@ -309,9 +345,11 @@ pander.summary.complexities <-
 #' @param ... ignored
 #' @export
 #' @noRd
-print.hagis.complexities <- function(x,
-                                     digits = max(3L, getOption("digits") - 3L),
-                                     ...) {
+print.hagis.complexities <- function(
+  x,
+  digits = max(3L, getOption("digits") - 3L),
+  ...
+) {
   cat("\nGrouped Complexities\n")
   print(x[[1]])
   cat("\n")
