@@ -1,11 +1,10 @@
-
 #' Create Binary Data Matrix From Pathotype Data
 #'
 #' @description Creates a binary data matrix from pathotype data representing
 #'  the pathotype of each isolate.  This binary data matrix can be used to
 #'  visualize beta-diversity of pathotypes using \CRANpkg{vegan} and
 #'  \CRANpkg{ape}.
-#'  
+#'
 #' @inheritParams summarize_gene
 #' @autoglobal
 #' @examplesIf interactive()
@@ -24,17 +23,11 @@
 #'                                     perc_susc = "perc.susc")
 #' final_matrix
 #'
-#' @return a binary matrix of pathotype data
-#' 
+#' @returns a binary matrix of pathotype data
+#'
 #' @export create_binary_matrix
-#' 
-create_binary_matrix <- function(x,
-                                 cutoff,
-                                 control,
-                                 sample,
-                                 gene,
-                                 perc_susc) {
-
+#'
+create_binary_matrix <- function(x, cutoff, control, sample, gene, perc_susc) {
   # check inputs and rename columns to work with this package
   x <- .check_inputs(
     .x = x,
@@ -48,16 +41,21 @@ create_binary_matrix <- function(x,
   # summarise the reactions, create susceptible.1 column, see
   # internal_functions.R
   x <- .binary_cutoff(.x = x, .cutoff = cutoff)
-  
+
   # remove susceptible so Beta diversity is only calculated based on pathotype
   x <- subset(x, gene != control)
-  
+
   x <- data.table(x[, c("sample", "gene", "susceptible.1")])
-         
+
   x <-
-    t(as.matrix(dcast(melt(x, id.vars = c("sample", "gene")),
-                    gene  ~ sample, value.var = "value"),
-              rownames = "gene"))
-  
+    t(as.matrix(
+      dcast(
+        melt(x, id.vars = c("sample", "gene")),
+        gene ~ sample,
+        value.var = "value"
+      ),
+      rownames = "gene"
+    ))
+
   return(x)
 }
