@@ -1,4 +1,3 @@
-
 #' Check User Inputs
 #'
 #' Checks and validates user inputs before running functions
@@ -12,23 +11,18 @@
 #' @param .gene column providing the gene(s) being tested. Character.
 #' @param .perc_susc column providing the percent susceptible reactions as a
 #' numeric value. Character.
-#' @keywords internal
 #' @autoglobal
-#' @noRd
+#' @dev
 .check_inputs <-
-  function(.x,
-           .cutoff,
-           .control,
-           .sample,
-           .gene,
-           .perc_susc) {
-    
-    if (!is.data.frame(.x) |
-        !is.numeric(.cutoff) |
-        !is.character(.control) |
-        !is.character(.sample) |
-        !is.character(.gene) |
-        !is.character(.perc_susc)) {
+  function(.x, .cutoff, .control, .sample, .gene, .perc_susc) {
+    if (
+      !is.data.frame(.x) ||
+        !is.numeric(.cutoff) ||
+        !is.character(.control) ||
+        !is.character(.sample) ||
+        !is.character(.gene) ||
+        !is.character(.perc_susc)
+    ) {
       stop(
         call. = FALSE,
         "You have failed to provide all necessary inputs or\n",
@@ -37,16 +31,20 @@
       )
     }
     dt <- as.data.table(.x)
-    setnames(dt,
-             c(.perc_susc, .gene, .sample),
-             c("perc_susc", "gene", "sample"))
+    setnames(
+      dt,
+      c(.perc_susc, .gene, .sample),
+      c("perc_susc", "gene", "sample")
+    )
 
     # validate that perc_susc is numeric
-    if (!is.numeric(dt$perc_susc))
+    if (!is.numeric(dt$perc_susc)) {
       stop("Data in the column `perc_susc` must be numeric.")
+    }
     # validate that no values in perc_susc < 0
-    if (any(dt$perc_susc < 0, na.rm = TRUE))
+    if (any(dt$perc_susc < 0, na.rm = TRUE)) {
       stop("Data in the column `perc_susc` must be non-negative.")
+    }
 
     # set col types for the necessary cols
     dt[, sample := as.character(sample)]
@@ -60,7 +58,7 @@
 #'
 #' @param .x A `data.table` containing the values to be summarised
 #' @param .cutoff Cutoff value for susceptibility
-#' @return A `data.table` that tallies the results by gene
+#' @returns A `data.table` that tallies the results by gene
 #' @keywords internal
 #' @autoglobal
 #' @noRd
