@@ -1,4 +1,3 @@
-
 # test individual pathotypes ---------------------------------------------------
 data(P_sojae_survey)
 diversities <- calculate_diversities(
@@ -13,11 +12,16 @@ diversities <- calculate_diversities(
 test_that("individual_pathotypes() returns a pander object", {
   expect_type(
     capture.output(
-      individual_pathotypes(x = diversities, type = "text")), "character")
+      individual_pathotypes(x = diversities, type = "text")
+    ),
+    "character"
+  )
 })
 
 test_that("individual_pathotypes() stops if object is not hagis.diversities
           object", {
-            expect_error(individual_pathotypes("y"),
-                         regexp = "This is not a hagis.diversities object.")
-          })
+  expect_error(
+    individual_pathotypes("y"),
+    regexp = "This is not a hagis.diversities object."
+  )
+})
